

TAPResults
=======================

.. currentmodule:: pyvo.dal.tap

.. autoclass:: TAPResults
   :show-inheritance:

   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~TAPResults.infos
      ~TAPResults.query_status

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: infos
   .. autoattribute:: query_status

   
   

   
   
   